<?php
class sbcApi {

	/*
	 * Functions name: please follow the same nomenclature than sbcapi (nodejs server)
	 */

	public	$socket 			=	null,
					$socket_error	= '';

	private	$_host = '127.0.0.1',
					$_port = '55542';

	private	$_sbc_conf = [],
					$_sbc_conf_path	= '/etc/beroNet/sbc.conf',
					$_sbc_conf_parameters	= [
						['php_key' => 'id', 'bash_key' => 'SBCVM_ID', 'regex' => '[0-9]+'],
					];

	private $_is_construct = false;

	function __construct() {
		// check sbc-api running
		if (!$this->_isSbcApiRunning()) {
			$this->socket_error = "SBC-API is not running";
			return;
		}

		// load sbc-conf file and set sbc-conf associative array
		if (!file_exists($this->_sbc_conf_path)) {
			return;
		}

		$sbc_conf = file_get_contents($this->_sbc_conf_path);	
		foreach ($this->_sbc_conf_parameters as $parameter) {
			if (preg_match('/'. $parameter['bash_key'] .'="('. $parameter['regex'] .')"/', $sbc_conf, $matched)) {
				$this->_sbc_conf[$parameter['php_key']] = $matched[1];
				unset($matched);
			}
			else {
				$this->_sbc_conf[$parameter['php_key']] = null;
			}
		}

		$this->_is_construct = true;
	}

	/* [PUBLIC METHODS] */

	public function deleteVpnServer($id) {
		if (!$this->_is_construct) {
			return false;
		}
		$uri = "/VPN/Server/$id";
		return $this->_sendRequest('delete');
	}

	public function getActionVpnServer(string $action) {
		if (!$this->_is_construct) {
			return false;
		}
		$method = 'get';
		switch ($action) {
			case 'client':
				$uri = "/VPN/Server/0/{$action}";
				break;
			default:
				return false;
		}
		return $this->_sendRequest($method, $uri);
	}

	public function updateVpnServer($id, $data = []) {
		if (!$this->_is_construct) {
			return false;
		}
		$uri = "/VPN/Server/$id";
		return $this->_sendRequest('put', $uri, $data);
	}

	/* [PRIVATE METHODS] */
	
	private function _isSbcApiRunning() {
		try {
			$this->socket = @fsockopen($this->_host, $this->_port, $errno, $errstr, 1);
		}
		catch (Exception $e) {
			// todo
			return false;
		}
		return $this->socket;
	}

	private function _sendRequest($method, $uri, $data = null, $options = []) {
		// TODO: write a generic function in the Helper class
		$api_url = "http://{$this->_host}:{$this->_port}$uri";
	
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $api_url);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);

		switch ($method) {
		case 'delete':
			curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "DELETE");
			break;
		case 'get':
			break;
		case 'post':
			curl_setopt($ch, CURLOPT_POST, 1);
			break;
		case 'put':
			curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "PUT");
			break;
		default:
			return false;
		}

		if (!is_null($data)) {
			curl_setopt( $ch, CURLOPT_HTTPHEADER, array('Content-Type:application/json'));
			curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
		}

		$response = curl_exec($ch);
		curl_close($ch);
		return $response;
	}
}
?>
